"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const fs = require("fs");
const path = require("path");
const fsNdjson = require("fs-ndjson");
const searchIssues_1 = require("../jira/searchIssues");
const teamUtils_1 = require("../misc/teamUtils");
const jiraUtils_1 = require("../misc/jiraUtils");
/*
    Fetches all initiatives
*/
const fetchInitiatives = async (userConfig, cacheDir, useCache, toDate) => {
    cli_ux_1.default.action.start('Fetching roadmap initiatives using: ' +
        userConfig.roadmap.jqlInitiatives +
        ' ');
    let issues = [];
    // If cache is enabled we don't fetch initiatives twice on the same day
    let today = new Date();
    if (toDate !== undefined) {
        today = new Date(toDate);
    }
    const initiativesCache = path.join(cacheDir, 'roadmap-initiatives-' + today.toJSON().slice(0, 10) + '.ndjson');
    if (useCache && fs.existsSync(initiativesCache)) {
        issues = fsNdjson.readFileSync(initiativesCache);
        // eslint-disable-next-line no-negated-condition
    }
    else if (toDate !== undefined) {
        issues = [];
    }
    else {
        const issuesJira = await searchIssues_1.default(userConfig.jira, userConfig.roadmap.jqlInitiatives, 'summary,status,' +
            userConfig.jira.fields.points +
            ',' +
            userConfig.jira.fields.originalPoints +
            ',issuetype,assignee');
        const issueFileStream = fs.createWriteStream(initiativesCache, {
            flags: 'w',
        });
        for (const issue of issuesJira) {
            const updatedIssue = Object.assign(Object.assign({}, issue), { host: userConfig.jira.host, jql: userConfig.roadmap.jqlInitiatives, team: teamUtils_1.getTeamFromAssignee(issue, userConfig.roadmap.teams), points: jiraUtils_1.returnTicketsPoints(issue, userConfig) });
            issueFileStream.write(JSON.stringify(jiraUtils_1.cleanIssue(updatedIssue)) + '\n');
            issues.push(jiraUtils_1.cleanIssue(updatedIssue));
        }
        issueFileStream.end();
    }
    cli_ux_1.default.action.stop(' done');
    return issues;
};
exports.default = fetchInitiatives;
