"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
    This function creates an empty object containing all of the expected days and weeks between the passed dats with zeroed values
*/
const date_fns_1 = require("date-fns");
const dateUtils_1 = require("../misc/dateUtils");
const initCalendar = (fromDate, toDate) => {
    const initObject = {
        days: {},
        weeks: {},
        open: {},
        forecast: {},
        health: {},
    };
    const days = [
        'Sunday',
        'Monday',
        'Tuesday',
        'Wednesday',
        'Thursday',
        'Friday',
        'Saturday',
    ];
    const emptyCompletion = {
        issues: { count: 0, velocity: 0 },
        points: { count: 0, velocity: 0 },
        list: [],
    };
    let toDay = new Date();
    toDay.setDate(toDay.getDate() - 1); // We don't process current day, only fetching closed issues on past days
    if (toDate !== undefined) {
        toDay = new Date(toDate);
    }
    const currentDate = dateUtils_1.formatDate(fromDate);
    // eslint-disable-next-line no-unmodified-loop-condition
    while (currentDate < toDay) {
        currentDate.setDate(currentDate.getDate() + 1);
        const weekTxt = date_fns_1.getYear(date_fns_1.endOfWeek(currentDate)) + '.' + date_fns_1.getWeek(currentDate);
        const weekStart = date_fns_1.formatISO(date_fns_1.startOfWeek(currentDate), {
            representation: 'date',
        });
        const currentDayKey = date_fns_1.formatISO(currentDate, {
            representation: 'date',
        });
        initObject.days[currentDayKey] = {
            date: date_fns_1.formatISO(currentDate, { representation: 'date' }),
            weekDay: currentDate.getDay(),
            weekDayJira: date_fns_1.formatISO(currentDate, { representation: 'date' }),
            weekDayTxt: days[currentDate.getDay()],
            weekNb: date_fns_1.getWeek(currentDate),
            weekTxt: weekTxt,
            completion: Object.assign({}, emptyCompletion),
            scopeChangeCompletion: Object.assign({}, emptyCompletion),
        };
        // tslint:disable-next-line: strict-type-predicates
        if (initObject.weeks[weekStart] === undefined) {
            initObject.weeks[weekStart] = {
                weekStart,
                weekEnd: date_fns_1.formatISO(date_fns_1.endOfWeek(currentDate), { representation: 'date' }),
                date: weekStart,
                weekNb: date_fns_1.getWeek(currentDate),
                weekTxt: weekTxt,
                weekJira: weekStart,
                completion: Object.assign({}, emptyCompletion),
                scopeChangeCompletion: Object.assign({}, emptyCompletion),
            };
        }
    }
    return initObject;
};
exports.default = initCalendar;
